nose2-gae
=========

.. image:: https://api.travis-ci.org/udacity/nose2-gae.png?branch=master
   :height: 19px
   :width: 77px
   :alt: nose2-gae Travis-CI build status
   :target: https://travis-ci.org/udacity/nose2-gae

Plugin for the `nose2 testrunner <https://nose2.readthedocs.org/en/latest/>`_ to run the tests in the Google App Engine environment, similar to `NoseGAE <https://github.com/Trii/NoseGAE>`_.

Currently in alpha version. The most notable missing features are the import/file sandbox and documentation :-).

